﻿using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace MigrateSharePointToWordPress.Controls
{
	/// <summary>
	/// Interaction logic for Credentials.xaml
	/// </summary>
	public partial class Credentials : UserControl
	{
		public static readonly DependencyProperty UrlProperty = DependencyProperty.Register("Url", typeof(string), typeof(Credentials), new PropertyMetadata(default(string)));
		public static readonly DependencyProperty UsernameProperty = DependencyProperty.Register("Username", typeof(string), typeof(Credentials), new PropertyMetadata(default(string)));
		public static readonly DependencyProperty PasswordProperty = DependencyProperty.Register("Password", typeof(string), typeof(Credentials), new PropertyMetadata(default(string)));
		public static readonly DependencyProperty UseDefaultCredentialsProperty = DependencyProperty.Register("UseDefaultCredentials", typeof(bool), typeof(Credentials), new PropertyMetadata(default(bool)));

		public string Url
		{
			get { return (string)GetValue(UrlProperty); }
			set { SetValue(UrlProperty, value); }
		}

		public string Username
		{
			get { return (string)GetValue(UsernameProperty); }
			set { SetValue(UsernameProperty, value); }
		}

		public string Password
		{
			get { return (string)GetValue(PasswordProperty); }
			set { SetValue(PasswordProperty, value); }
		}

		public bool UseDefaultCredentials
		{
			get { return (bool)GetValue(UseDefaultCredentialsProperty); }
			set { SetValue(UseDefaultCredentialsProperty, value); }
		}

		public Color UsernameBorderColor { get; set; }
		public Color PasswordBorderColor { get; set; }
		public bool IsValid { get; set; }

		public Credentials()
		{
			InitializeComponent();
		}

		public NetworkCredential GetCredentials()
		{
			if (UseDefaultCredentials)
				return CredentialCache.DefaultNetworkCredentials;

			return new NetworkCredential(UsernameInput.Text, PasswordInput.Password);
		}

		private void ValidateControl(object sender, RoutedEventArgs e)
		{
			if (!UseDefaultCredentials)
			{
				if (string.IsNullOrEmpty(Username))
					IsValid = false;

				if (string.IsNullOrEmpty(Password))
					IsValid = false;
			}
		}

		public CredentialData GetCredentialData()
		{
			return new CredentialData {Url = Url, Username = Username, Password = Password};
		}
	}
}
