using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Xml.Linq;

namespace MigrateSharePointToWordPress
{
	public static class Extensions
	{
		private const string Seperator = ";#";

		public static string GetAttributeValue(this XElement element, string attributeName)
		{
			XAttribute value = element.Attribute(attributeName);
			return value != null ? value.Value : null;
		}

		public static int GetLookupId(this string lookupValue)
		{
			if (string.IsNullOrEmpty(lookupValue))
				return 0;

			var values = lookupValue.Split(new[] {";#"}, StringSplitOptions.RemoveEmptyEntries);
			return Convert.ToInt32(values[0]);
		}
		
		public static List<string> GetLookupValues(this string lookupValue)
		{
			var lookupValues = new List<string>();
			if (string.IsNullOrEmpty(lookupValue))
				return lookupValues;

			string[] items = lookupValue.Split(new[] {Seperator}, StringSplitOptions.RemoveEmptyEntries);
			// now the values look like [11,test,11,test2]
			for (int i = 1; i < items.Length; i=i+2)
			{
				lookupValues.Add(items[i]);
			}
			return lookupValues;
		}

		/// <summary>
		/// The slug is the URL-friendly version of the name. It is usually all lowercase and contains only letters, numbers, and hyphens.
		/// </summary>
		/// <param name="str"></param>
		/// <returns></returns>
		public static string ToSlug(this string str)
		{
			str = str.Replace(" ", string.Empty);
			return str;
		}

		public static void ReportProgress(this BackgroundWorker worker, ProgressReport data)
		{
			worker.ReportProgress(0, data);
		}
	}
}