using System;
using System.Diagnostics;
using System.Web;

namespace MigrateSharePointToWordPress.Source
{
	public class LocalResource
	{
		/// <summary>
		/// makes the passed sourceFileUrl absolute to the sourceBlogUrl
		/// </summary>
		/// <param name="sourceBlogUrl">e.g. https://www.hezser.de/blog</param>
		/// <param name="sourceFileUrl"></param>
		[DebuggerStepThrough]
		public LocalResource(string sourceBlogUrl, string sourceFileUrl)
		{
			OriginalSourceUrl = sourceFileUrl;
			// need to create absolute URL
			var uri = new Uri(sourceFileUrl, UriKind.RelativeOrAbsolute);
			if (!uri.IsAbsoluteUri)
			{
				uri = new Uri(new Uri(sourceBlogUrl, UriKind.Absolute), sourceFileUrl);
			}
			SourceUrl = HttpUtility.UrlDecode(uri.AbsoluteUri);
		}

		/// <summary>
		/// the source URL to be able to replace later
		/// </summary>
		public string OriginalSourceUrl { get; set; }

		/// <summary>
		/// The Absolute URL
		/// </summary>
		public string SourceUrl { get; set; }

		/// <summary>
		/// identifies a Post, so references to local posts can be translated to the new post in the destination
		/// </summary>
		public int SourcePostId { get; set; }

		/// <summary>
		/// The Absolute Url
		/// </summary>
		public string DestinationUrl { get; set; }

		/// <summary>
		/// Has the resource already been uploaded?
		/// </summary>
		public bool AlreadyUploaded { get; set; }
	}
}